@@ -17,11 +17,11 @@ void robust_synth_loglik (double *y, int *dim, double *ydat, double *loglik) {
   int ncol = dim[1];
   double alpha = 2.0, beta = 1.25;
   double w[nrow], tau[ncol], work[ncol];
-  int info = 0, ione = 1;
+  int info = 0;
   double one = 1.0;
   double *y1, *y2, *yp;
   double x, xx, wbar, d, d0, rss, half_log_det;
-  int i, j, k;
+  int i, j;
 
   half_log_det = ncol*M_LN_SQRT_2PI;
 
