@@ -1,9 +1,9 @@
 library(pomp)
 
-data(ricker)
-
 pdf(file="ricker-spect.pdf")
 
+data(ricker)
+
 set.seed(6457673L)
 
 sp <- spect(
@@ -15,6 +15,10 @@ sp <- spect(
 plot(sp)
 summary(sp)
 
+spp <- spect.match(sp,eval.only=TRUE)
+plot(spp)
+summary(spp)
+
 po <- ricker
 coef(po,"log.r") <- log(5)
 sp <- spect(
